==> jc-1.4.0.tar.gz: soot/jimple/internal/AbstractUnopExpr.h <==
// public abstract class soot.jimple.internal.AbstractUnopExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2880d6831146619b soot_jimple_internal_AbstractUnopExpr

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_internal_AbstractUnopExpr_H_
#define _JC_soot_jimple_internal_AbstractUnopExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_Value$object;
struct _jc_soot_ValueBox$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_AbstractUnopExpr$sub_refs	_jc_soot_jimple_internal_AbstractUnopExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs	_jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractUnopExpr$refs	_jc_soot_jimple_internal_AbstractUnopExpr$refs;
typedef struct _jc_soot_jimple_internal_AbstractUnopExpr$nonrefs	_jc_soot_jimple_internal_AbstractUnopExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractUnopExpr$object	_jc_soot_jimple_internal_AbstractUnopExpr$object;

typedef const struct _jc_soot_jimple_internal_AbstractUnopExpr$vmethods	_jc_soot_jimple_internal_AbstractUnopExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_AbstractUnopExpr$vtable	_jc_soot_jimple_internal_AbstractUnopExpr$vtable;
typedef const struct _jc_soot_jimple_internal_AbstractUnopExpr$vtype	_jc_soot_jimple_internal_AbstractUnopExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_AbstractUnopExpr$method$_init$42e949dc1de144e1(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_AbstractUnopExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *);
extern struct _jc_object *_jc_soot_jimple_internal_AbstractUnopExpr$method$getOp$e2654b523ebb5830(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *);
extern struct _jc_object *_jc_soot_jimple_internal_AbstractUnopExpr$method$getOpBox$ec0457a4bea1aaf2(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *);
extern struct _jc_object *_jc_soot_jimple_internal_AbstractUnopExpr$method$getUseBoxes$8c22fb3c6dc4d01e(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *);
extern void _jc_soot_jimple_internal_AbstractUnopExpr$method$setOp$1ff2439eaaad3f5f(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_AbstractUnopExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_AbstractUnopExpr$method_info$getOp$e2654b523ebb5830;
extern _jc_method _jc_soot_jimple_internal_AbstractUnopExpr$method_info$getOpBox$ec0457a4bea1aaf2;
extern _jc_method _jc_soot_jimple_internal_AbstractUnopExpr$method_info$getUseBoxes$8c22fb3c6dc4d01e;
extern _jc_method _jc_soot_jimple_internal_AbstractUnopExpr$method_info$setOp$1ff2439eaaad3f5f;

// Virtual methods structure
struct _jc_soot_jimple_internal_AbstractUnopExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *);
	struct _jc_object	*(*getOp$e2654b523ebb5830)(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *);
	struct _jc_object	*(*getOpBox$ec0457a4bea1aaf2)(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *);
	struct _jc_object	*(*getUseBoxes$8c22fb3c6dc4d01e)(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *);
	void	(*setOp$1ff2439eaaad3f5f)(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_internal_AbstractUnopExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractUnopExpr$vmethods	soot_jimple_internal_AbstractUnopExpr;
};

// Vtype
struct _jc_soot_jimple_internal_AbstractUnopExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_AbstractUnopExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractUnopExpr$sub_refs {
	struct _jc_object	*opBox;
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractUnopExpr$refs {
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_refs	soot_jimple_internal_AbstractUnopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractUnopExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs	soot_jimple_internal_AbstractUnopExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_AbstractUnopExpr$object {
	_jc_soot_jimple_internal_AbstractUnopExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_AbstractUnopExpr$vtype	*vtype;
	_jc_soot_jimple_internal_AbstractUnopExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_AbstractUnopExpr$vtype _jc_soot_jimple_internal_AbstractUnopExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_AbstractUnopExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_AbstractUnopExpr$class_object;

#endif	/* _JC_soot_jimple_internal_AbstractUnopExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/AbstractUnopExpr.h <==
// public abstract class soot.jimple.internal.AbstractUnopExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2880d6831146619b soot_jimple_internal_AbstractUnopExpr

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_internal_AbstractUnopExpr_H_
#define _JC_soot_jimple_internal_AbstractUnopExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_Value$object;
struct _jc_soot_ValueBox$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_AbstractUnopExpr$sub_refs	_jc_soot_jimple_internal_AbstractUnopExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs	_jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractUnopExpr$refs	_jc_soot_jimple_internal_AbstractUnopExpr$refs;
typedef struct _jc_soot_jimple_internal_AbstractUnopExpr$nonrefs	_jc_soot_jimple_internal_AbstractUnopExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractUnopExpr$object	_jc_soot_jimple_internal_AbstractUnopExpr$object;

typedef const struct _jc_soot_jimple_internal_AbstractUnopExpr$vmethods	_jc_soot_jimple_internal_AbstractUnopExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_AbstractUnopExpr$vtable	_jc_soot_jimple_internal_AbstractUnopExpr$vtable;
typedef const struct _jc_soot_jimple_internal_AbstractUnopExpr$vtype	_jc_soot_jimple_internal_AbstractUnopExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_AbstractUnopExpr$method$_init$42e949dc1de144e1(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_AbstractUnopExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_internal_AbstractUnopExpr$method$getOp$e2654b523ebb5830(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_internal_AbstractUnopExpr$method$getOpBox$ec0457a4bea1aaf2(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_internal_AbstractUnopExpr$method$getUseBoxes$8c22fb3c6dc4d01e(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_AbstractUnopExpr$method$setOp$1ff2439eaaad3f5f(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_AbstractUnopExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_AbstractUnopExpr$method_info$getOp$e2654b523ebb5830;
extern _jc_method _jc_soot_jimple_internal_AbstractUnopExpr$method_info$getOpBox$ec0457a4bea1aaf2;
extern _jc_method _jc_soot_jimple_internal_AbstractUnopExpr$method_info$getUseBoxes$8c22fb3c6dc4d01e;
extern _jc_method _jc_soot_jimple_internal_AbstractUnopExpr$method_info$setOp$1ff2439eaaad3f5f;

// Virtual methods structure
struct _jc_soot_jimple_internal_AbstractUnopExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getOp$e2654b523ebb5830)(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getOpBox$ec0457a4bea1aaf2)(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getUseBoxes$8c22fb3c6dc4d01e)(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *) _JC_JCNI_ATTR;
	void	(*setOp$1ff2439eaaad3f5f)(_jc_env *, struct _jc_soot_jimple_internal_AbstractUnopExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_AbstractUnopExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractUnopExpr$vmethods	soot_jimple_internal_AbstractUnopExpr;
};

// Vtype
struct _jc_soot_jimple_internal_AbstractUnopExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_AbstractUnopExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractUnopExpr$sub_refs {
	struct _jc_object	*opBox;
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractUnopExpr$refs {
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_refs	soot_jimple_internal_AbstractUnopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractUnopExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs	soot_jimple_internal_AbstractUnopExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_AbstractUnopExpr$object {
	_jc_soot_jimple_internal_AbstractUnopExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_AbstractUnopExpr$vtype	*vtype;
	_jc_soot_jimple_internal_AbstractUnopExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_AbstractUnopExpr$vtype _jc_soot_jimple_internal_AbstractUnopExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_AbstractUnopExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_AbstractUnopExpr$class_object;

#endif	/* _JC_soot_jimple_internal_AbstractUnopExpr_H_ */
